-- Created by NuclearTonic
-- If reusing this code, please keep the name of the original author listed
-- in respect for borrowing said authors code.
-- RESPECT!

import "Turbine";
import "Turbine.UI";
import "Turbine.UI.Lotro";
import "Tonic.UI.AutoListBox";
import "Tonic.UI.MenuUtils";

buttonWidth = 85;
selectionWidth = 160;
selectionHeight = 20;
startFromTop = 39;
insideBoxXOffset = selectionWidth + 5;
insideBoxYOffset = startFromTop + 200;

QuickslotsMenu = class( Tonic.UI.AutoListBox );

function QuickslotsMenu:Constructor()
	Tonic.UI.AutoListBox.Constructor( self );
	
	self.utils = Tonic.UI.MenuUtils();
	
	self.upperBar = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Vertical, 0, 0, 0, 0 );
	self.utils:AddLabelBox( self.upperBar, "Click Add Bar to start using tonic bars or select a QuickBar to edit.", selectionWidth + 250, selectionHeight + 10 );
	
	local addButton = Turbine.UI.Lotro.Button();
	addButton:SetText( "Add Bar" );
	addButton:SetSize( buttonWidth, selectionHeight );
	addButton.MouseClick = function( sender, args )
		local barid = maitre_d:Add( QUICKSLOTBAR );
		self.barList:AddItem( barid, barid );
	end
	self.upperBar:AddItem( addButton );
	
	self.utils:AddLabelBox( self, "Editing Settings for Bar:", selectionWidth + 100, selectionHeight );
	
	self.barList = Tonic.UI.ComboBox();
	self.barList:SetSize( 200, 20 );
	self.barList:SetParent( self );
    self.barList.SelectedIndexChanged = function(sender, args)
		local settings = theSettingsManager:GetSettings();
		settings.selectedBar = tonumber(args.selection);
		self.scrollBox:SetVisible( true );
		menu:SetupMainMenuDisplay( QUICKSLOT_MODE );
		maitre_d:RefreshBars();
	end
	self.upperBar:AddItem( self.barList );
	
	self:AddSettings();
	self:AddItem( self.upperBar );
	self:AddTriggers();
	self:AddColorOptions();
	
	self.scrollBox = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0 );

	self.sidebar = Turbine.UI.Lotro.ScrollBar();
	self.sidebar:SetParent( self.scrollBox );
	self.sidebar:SetOrientation( Turbine.UI.Orientation.Vertical );
	
	self.scrollBox:AddItem( self.settingsBox );
	self.scrollBox:AddItem( self.sidebar );
	self.settingsBox:SetVerticalScrollBar( self.sidebar );
	self:AddItem( self.scrollBox );
	self.scrollBox:SetVisible( false );
		
	self.sidebar:SetSize ( 8, windowHeight - self.upperBar:GetHeight() - 105 );
	self.settingsBox:SetSize( self.settingsBox:GetWidth(), windowHeight - self.upperBar:GetHeight() - 105 );
end


function QuickslotsMenu:AddTriggers()
	local bgColor = Turbine.UI.Color(1,0.2,0.3,0.5);

	self.triggerDownWindow = Turbine.UI.Control();
    self.triggerDownWindow:SetBackColor( unselectedColor );
    self.triggerDownWindow:SetZOrder(30);
    self.triggerDownWindow:SetVisible(false);
	self.triggerDownWindow:SetParent( self );
	self.triggerDownWindow:SetBackColor( bgColor );
	
	self.triggerDownWindow.MouseLeave = function(sender, args)
		local x, y = self.triggerDownWindow:GetMousePosition();
		local xSize, ySize = self.triggerDownWindow:GetSize();
		if ( x < 0 or y < 0 or x > xSize or y > ySize ) then
			self.triggerDownWindow:SetVisible( false );
		end
	end
	
	self.triggerDownWindow.VisibleChanged = function(sender, args)
		if ( self.triggerDownWindow:IsVisible() == true ) then
			self.label1:SetVisible( false );
			self.label2:SetVisible( false );
			self.label3:SetVisible( false );
			self.label4:SetVisible( false );
		else
			self.label1:SetVisible( true );
			self.label2:SetVisible( true );
			self.label3:SetVisible( true );
			self.label4:SetVisible( true );			
		end
	end
	
	local box0 = self.utils:AddAutoListBox( self.triggerDownWindow, Turbine.UI.Orientation.Vertical, 0, 0, 0, 0 );
	local box1 = self.utils:AddAutoListBox( self.triggerDownWindow, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0 );
	local box2 = self.utils:AddAutoListBox( self.triggerDownWindow, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0 );
	local box3 = self.utils:AddAutoListBox( self.triggerDownWindow, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0 );
	local box4 = self.utils:AddAutoListBox( self.triggerDownWindow, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0 );
	
	box0:SetBackColor( bgColor );
	box1:SetBackColor( bgColor );
	box2:SetBackColor( bgColor );
	box3:SetBackColor( bgColor );
	box4:SetBackColor( bgColor );
	
	local dispLabel = self.utils:AddLabelBox( box0, "Display this bar when:", selectionWidth + 100, selectionHeight + 5 );
	dispLabel:SetBackColor( bgColor );
	
	self.combatBarCheckBox  = self.utils:AddCheckBox( box1, "In Combat", selectionWidth, selectionHeight );
	self.combatBarCheckBox:SetBackColor( bgColor );
	self.altBarCheckBox     = self.utils:AddCheckBox( box1, "Alt Pressed", selectionWidth, selectionHeight );
	self.altBarCheckBox:SetBackColor( bgColor );
	self.controlBarCheckBox = self.utils:AddCheckBox( box2, "Ctrl Pressed", selectionWidth, selectionHeight );
	self.controlBarCheckBox:SetBackColor( bgColor );
	self.shiftBarCheckBox   = self.utils:AddCheckBox( box2, "Shift Pressed", selectionWidth, selectionHeight );
	self.shiftBarCheckBox:SetBackColor( bgColor );
	
	self.poisonBarCheckBox  = self.utils:AddCheckBox( box3, "Poisoned", selectionWidth, selectionHeight );
	self.poisonBarCheckBox:SetBackColor( bgColor );
	self.woundBarCheckBox     = self.utils:AddCheckBox( box3, "Wounded", selectionWidth, selectionHeight );
	self.woundBarCheckBox:SetBackColor( bgColor );
	self.fearBarCheckBox = self.utils:AddCheckBox( box4, "Feared", selectionWidth, selectionHeight );
	self.fearBarCheckBox:SetBackColor( bgColor );
	self.diseaseBarCheckBox   = self.utils:AddCheckBox( box4, "Diseased", selectionWidth, selectionHeight );
	self.diseaseBarCheckBox:SetBackColor( bgColor );
	
	box0:AddItem( box1 );
	box0:AddItem( box2 );
	box0:AddItem( box3 );
	box0:AddItem( box4 );

	local blankLabel = self.utils:AddLabelBox( box0, "", selectionWidth + 100, selectionHeight );
	blankLabel:SetBackColor( bgColor );
	
	local box6 = self.utils:AddAutoListBox( self.triggerDownWindow, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0 );
	box6:SetBackColor( bgColor );
	self.healthTriggerCheckBox = self.utils:AddCheckBox( box0, "Health Drops Below this %:", selectionWidth + 100, selectionHeight );
	self.healthTriggerCheckBox:SetBackColor( bgColor );
	self.healthNum = self.utils:AddLabelBox( box6, "", 30, selectionHeight );
	self.healthNum:SetBackColor( bgColor );
	self.healthSB = self.utils:AddScrollBar( box6, 0, 0, 100, 200, selectionHeight / 2 );
	self.healthSB:SetBackColor( bgColor );
	box0:AddItem( box6 );
	
	
	local box7 = self.utils:AddAutoListBox( self.triggerDownWindow, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0 );
	box7:SetBackColor( bgColor );
	self.powerTriggerCheckBox = self.utils:AddCheckBox( box0, "Power Drops Below this %:", selectionWidth + 100, selectionHeight );
	self.powerTriggerCheckBox:SetBackColor( bgColor );
	self.powerNum = self.utils:AddLabelBox( box7, "", 30, selectionHeight );
	self.powerNum:SetBackColor( bgColor );
	self.powerSB = self.utils:AddScrollBar( box7, 0, 0, 100, 200, selectionHeight / 2 );
	self.powerSB:SetBackColor( bgColor );
	box0:AddItem( box7 );
	
	local triggerButton = Turbine.UI.Lotro.Button();
	triggerButton:SetText( "Hide Trigger Options" );
	triggerButton:SetSize( buttonWidth + 100, selectionHeight );
	triggerButton.MouseClick = function( sender, args )
		self.triggerDownWindow:SetVisible( false );
	end
	box0:AddItem( triggerButton );
	
	self.triggerDownWindow:SetSize( self.settingsBox:GetWidth(), box0:GetHeight() );
end

function QuickslotsMenu:DisplayTriggers( showQuickslots )
	self.triggerDownWindow:SetVisible( showQuickslots );

	local localBarSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
	
	self.combatBarCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.isCombatBar = self.combatBarCheckBox.IsChecked;
		self:ShouldCheckBeVisible( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end	
	self.combatBarCheckBox:SetChecked( localBarSettings.isCombatBar );
	self.altBarCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.isAlt = self.altBarCheckBox.IsChecked;
		self:ShouldCheckBeVisible( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end	
	self.altBarCheckBox:SetChecked( localBarSettings.isAlt );
	self.controlBarCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.isControl = self.controlBarCheckBox.IsChecked;
		self:ShouldCheckBeVisible( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.controlBarCheckBox:SetChecked( localBarSettings.isControl );
	self.shiftBarCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.isShift = self.shiftBarCheckBox.IsChecked;
		self:ShouldCheckBeVisible( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.shiftBarCheckBox:SetChecked( localBarSettings.isShift );
	
	self.poisonBarCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.displayOnPoison = self.poisonBarCheckBox.IsChecked;
		self:ShouldCheckBeVisible( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.poisonBarCheckBox:SetChecked( localBarSettings.displayOnPoison );
	self.woundBarCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.displayOnWound = self.woundBarCheckBox.IsChecked;
		self:ShouldCheckBeVisible( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.woundBarCheckBox:SetChecked( localBarSettings.displayOnWound );
	self.fearBarCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.displayOnFear = self.fearBarCheckBox.IsChecked;
		self:ShouldCheckBeVisible( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.fearBarCheckBox:SetChecked( localBarSettings.displayOnFear );
	self.diseaseBarCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.displayOnDisease = self.diseaseBarCheckBox.IsChecked;
		self:ShouldCheckBeVisible( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.diseaseBarCheckBox:SetChecked( localBarSettings.displayOnDisease );
	
	self.healthTriggerCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.displayOnHealth = self.healthTriggerCheckBox.IsChecked;
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end	
	self.healthTriggerCheckBox:SetChecked( localBarSettings.displayOnHealth );
	
	self.healthSB.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.healthTrigger = self.healthSB:GetValue() / 100;
		self.healthNum:SetText( barSettings.healthTrigger * 100 );
		self:SetColors( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.healthSB:SetValue( localBarSettings.healthTrigger * 100 );
	self.healthNum:SetText( localBarSettings.healthTrigger * 100 );
	
	self.powerTriggerCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.displayOnPower = self.powerTriggerCheckBox.IsChecked;
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end	
	self.powerTriggerCheckBox:SetChecked( localBarSettings.displayOnPower );

	self.powerSB.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.powerTrigger = self.powerSB:GetValue() / 100;
		self.powerNum:SetText( barSettings.powerTrigger * 100 );
		self:SetColors( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.powerSB:SetValue( localBarSettings.powerTrigger * 100 );
	self.powerNum:SetText( localBarSettings.powerTrigger * 100 );
end

function QuickslotsMenu:AddColorOptions()
	local bgColor = Turbine.UI.Color(1,0.2,0.3,0.5);

	self.colorDownWindow = Turbine.UI.Control();
    self.colorDownWindow:SetBackColor( unselectedColor );
    self.colorDownWindow:SetZOrder(10);
    self.colorDownWindow:SetVisible(false);
	self.colorDownWindow:SetParent( self );
	self.colorDownWindow:SetBackColor( bgColor );
	
	self.colorDownWindow.MouseLeave = function(sender, args)
		local x, y = self.colorDownWindow:GetMousePosition();
		local xSize, ySize = self.colorDownWindow:GetSize();
		if ( x < 0 or y < 0 or x > xSize or y > ySize ) then
			self.colorDownWindow:SetVisible( false );
		end
	end
	
	self.colorDownWindow.VisibleChanged = function(sender, args)
		if ( self.colorDownWindow:IsVisible() == true ) then
			self.label1:SetVisible( false );
			self.label2:SetVisible( false );
			self.label3:SetVisible( false );
			self.label4:SetVisible( false );
		else
			self.label1:SetVisible( true );
			self.label2:SetVisible( true );
			self.label3:SetVisible( true );
			self.label4:SetVisible( true );			
		end
	end
	local box0 = self.utils:AddAutoListBox( self.colorDownWindow, Turbine.UI.Orientation.Vertical );
	box0:SetBackColor( bgColor );
	
	local box8a = self.utils:AddAutoListBox( self.colorDownWindow, Turbine.UI.Orientation.Vertical );
	box8a:SetBackColor( bgColor );
	local box8b = self.utils:AddAutoListBox( self.box8a, Turbine.UI.Orientation.Horizontal );
	box8b:SetBackColor( bgColor );
	local box8c = self.utils:AddAutoListBox( self.box8a, Turbine.UI.Orientation.Horizontal );
	box8c:SetBackColor( bgColor );
	local box8d = self.utils:AddAutoListBox( self.box8a, Turbine.UI.Orientation.Horizontal );
	box8d:SetBackColor( bgColor );
	local box8e = self.utils:AddAutoListBox( self.box8a, Turbine.UI.Orientation.Horizontal );
	box8e:SetBackColor( bgColor );

	self.useBackgroundCheckBox  = self.utils:AddCheckBox( box8a, "Use Background Color on Bar", selectionWidth + 150, selectionHeight );
	self.useBackgroundCheckBox:SetBackColor( bgColor );

	local lb = self.utils:AddLabelBox( box8b, "Red:", 50, selectionHeight );
	lb:SetBackColor( bgColor );
	self.bgRNum = self.utils:AddLabelBox( box8b, "", 50, selectionHeight );
	self.bgRNum:SetBackColor( bgColor );
	self.bgRSB = self.utils:AddScrollBar( box8b, 0, 0, 100, 200, selectionHeight / 2 );
	self.bgRSB:SetBackColor( bgColor );

	lb = self.utils:AddLabelBox( box8c, "Green:", 50, selectionHeight );
	lb:SetBackColor( bgColor );
	self.bgGNum = self.utils:AddLabelBox( box8c, "", 50, selectionHeight );
	self.bgGNum:SetBackColor( bgColor );
	self.bgGSB = self.utils:AddScrollBar( box8c, 0, 0, 100, 200, selectionHeight / 2 );
	self.bgGSB:SetBackColor( bgColor );

	lb = self.utils:AddLabelBox( box8d, "Blue:", 50, selectionHeight );
	lb:SetBackColor( bgColor );
	self.bgBNum = self.utils:AddLabelBox( box8d, "", 50, selectionHeight );
	self.bgBNum:SetBackColor( bgColor );
	self.bgBSB = self.utils:AddScrollBar( box8d, 0, 0, 100, 200, selectionHeight / 2 );
	self.bgBSB:SetBackColor( bgColor );

	self.bgANum = self.utils:AddLabelBox( box8e, "", 50, selectionHeight );
	self.bgANum:SetBackColor( bgColor );
	self.bgASB = self.utils:AddScrollBar( box8e, 0, 0, 100, 200, selectionHeight / 2 );
	self.bgASB:SetBackColor( bgColor );

	box8a:AddItem( box8b );
	box8a:AddItem( box8c );
	box8a:AddItem( box8d );
	lb = self.utils:AddLabelBox( box8a, "Bar Opasity:", 100, selectionHeight );
	lb:SetBackColor( bgColor );
	box8a:AddItem( box8e );

	local box4a = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Vertical );
	box4a:SetBackColor( bgColor );
	local box4b = self.utils:AddAutoListBox( self.box4a, Turbine.UI.Orientation.Horizontal );
	box4b:SetBackColor( bgColor );

	self.fadeOpacityNum1 = self.utils:AddLabelBox( box4a, "", 50, selectionHeight );
	self.fadeOpacityNum1:SetBackColor( bgColor );
	self.fadeOpacityNum2 = self.utils:AddLabelBox( box4a, "Shortcut Opacity:", 150, selectionHeight );
	self.fadeOpacityNum2:SetBackColor( bgColor );
	self.fadeOpacityNum3 = self.utils:AddLabelBox( box4b, "", 50, selectionHeight );
	self.fadeOpacityNum3:SetBackColor( bgColor );
	self.fadeOpacitySelection = self.utils:AddScrollBar( box4b, 0, 0, 100, 200, selectionHeight / 2 );
	self.fadeOpacitySelection:SetBackColor( bgColor );
	
	box4a:AddItem( box4b );
	self.useFadingCheckBox  = self.utils:AddCheckBox( box4a, "Remove opacity when moused over?", selectionWidth + 200, selectionHeight );
	self.useFadingCheckBox:SetBackColor( bgColor );
	
	box0:AddItem( box8a );
	box0:AddItem( box4a );

	local colorButton = Turbine.UI.Lotro.Button();
	colorButton:SetText( "Hide Color Options" );
	colorButton:SetSize( buttonWidth + 100, selectionHeight );
	colorButton.MouseClick = function( sender, args )
		self.colorDownWindow:SetVisible( false );
	end
	box0:AddItem( colorButton );
	
	self.colorDownWindow:SetSize( self.settingsBox:GetWidth(), box0:GetHeight() );
end

function QuickslotsMenu:DisplayColorOptions( showQuickslots )
	self.colorDownWindow:SetVisible( showQuickslots );

	local localBarSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
	
	self.useBackgroundCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.useBackgroundColor = self.useBackgroundCheckBox.IsChecked;
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end	
	self.useBackgroundCheckBox:SetChecked( localBarSettings.useBackgroundColor );
	self.bgRSB.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.backgroundColorRed = self.bgRSB:GetValue() / 100;
		self.bgRNum:SetText( barSettings.backgroundColorRed );
		self:SetColors( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.bgRSB:SetValue( localBarSettings.backgroundColorRed * 100 );
	self.bgGSB.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.backgroundColorGreen = self.bgGSB:GetValue() / 100;
		self.bgGNum:SetText( barSettings.backgroundColorGreen );
		self:SetColors( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.bgGSB:SetValue( localBarSettings.backgroundColorGreen * 100 );
	self.bgBSB.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.backgroundColorBlue = self.bgBSB:GetValue() / 100;
		self.bgBNum:SetText( barSettings.backgroundColorBlue );
		self:SetColors( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.bgBSB:SetValue( localBarSettings.backgroundColorBlue * 100 );
	self.bgASB.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.opacity = self.bgASB:GetValue() / 100;
		self.bgANum:SetText( barSettings.opacity );
		self:SetColors( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.bgASB:SetValue( localBarSettings.opacity * 100 );

	
	self.fadeOpacitySelection.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.fadeOpacity = self.fadeOpacitySelection:GetValue() / 100;
		self.fadeOpacityNum3:SetText( barSettings.fadeOpacity );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.fadeOpacitySelection:SetValue( localBarSettings.fadeOpacity * 100 );
	self.useFadingCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.useFading = self.useFadingCheckBox.IsChecked;
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end	
	self.useFadingCheckBox:SetChecked( localBarSettings.useFading );

	self.fadeOpacityNum3:SetText( localBarSettings.fadeOpacity );
	self.spacingNum:SetText( localBarSettings.quickslotSpacing );
	self.sizeNum:SetText( localBarSettings.quickslotSize );
		
	self.bgRNum:SetText( localBarSettings.backgroundColorRed );
	self.bgGNum:SetText( localBarSettings.backgroundColorGreen );
	self.bgBNum:SetText( localBarSettings.backgroundColorBlue );
	self.bgANum:SetText( localBarSettings.opacity );

	self:SetColors( localBarSettings );
end

function QuickslotsMenu:AddSettings()
	self.settingsBox = self.utils:AddAutoListBox( self.scrollBox, Turbine.UI.Orientation.Vertical, 0, 0, 0, 0 );

	self.utils:AddLabelBox( self.settingsBox, "", 50, selectionHeight );

	local box0 = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0 );
	self.utils:AddLabelBox( box0, "Bar Name:", 80, selectionHeight );
	self.barName = self.utils:AddTextBox(box0, "", selectionWidth, selectionHeight + 10 );

	local nameButton = Turbine.UI.Lotro.Button();
	nameButton:SetText( "Set Name" );
	nameButton:SetSize( buttonWidth, selectionHeight );
	nameButton.MouseClick = function( sender, args )
		local selection = self.barList:GetSelection();
		local barSettings = theSettingsManager:GetBarSettings( selection );
		barSettings.barName = self.barName:GetText();
		self:RefreshComboBox( self.barList:GetSelection() );
		theSettingsManager:SetBarSettings( selection, barSettings );
	end
	box0:AddItem( nameButton );
	
	self.settingsBox:AddItem( box0 );
	local box1 = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Horizontal );	
	self.barVisibleCheckBox = self.utils:AddCheckBox( box1, "Visible", selectionWidth, selectionHeight );
	self.barLockedCheckBox = self.utils:AddCheckBox( box1, "Locked", selectionWidth, selectionHeight );
	
	self.settingsBox:AddItem( box1 );
	local box2a = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Vertical );
	local box2b = self.utils:AddAutoListBox( self.box2a, Turbine.UI.Orientation.Horizontal );

	self.label1 = self.utils:AddLabelBox( box2a, "Number of Total Quickslots:", selectionWidth + 100, selectionHeight + 5 );
	self.sbNum = self.utils:AddLabelBox( box2b, "", 50, selectionHeight );
	self.sb = self.utils:AddScrollBar( box2b, 1, 1, 1000, 200, selectionHeight / 2 );

	box2a:AddItem( box2b );
	self.settingsBox:AddItem( box2a );
	local box3a = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Vertical );
	local box3b = self.utils:AddAutoListBox( self.box3a, Turbine.UI.Orientation.Horizontal );
	
	self.label2 = self.utils:AddLabelBox( box3a, "Number of Columns of Quickslots:", selectionWidth + 100, selectionHeight + 5 );
	self.sb2Num = self.utils:AddLabelBox( box3b, "", 50, selectionHeight );
	self.sb2 = self.utils:AddScrollBar( box3b, 1, 1, 50, 200, selectionHeight / 2 );

	box3a:AddItem( box3b );
	self.settingsBox:AddItem( box3a );
	local box5a = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Vertical );
	local box5b = self.utils:AddAutoListBox( self.box5a, Turbine.UI.Orientation.Horizontal );
	
	self.label3 = self.utils:AddLabelBox( box5a, "Space Between Quickslots:", selectionWidth + 100, selectionHeight + 5 );
	self.spacingNum = self.utils:AddLabelBox( box5b, "", 50, selectionHeight );
	self.spacingSB = self.utils:AddScrollBar( box5b, 1, 0, 50, 200, selectionHeight / 2 );
	
	box5a:AddItem( box5b );
	self.settingsBox:AddItem( box5a );
	local box6a = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Vertical );
	local box6b = self.utils:AddAutoListBox( self.box6a, Turbine.UI.Orientation.Horizontal );

	self.label4 = self.utils:AddLabelBox( box6a, "Quickslot Size:", selectionWidth + 50, selectionHeight + 5 );
	self.sizeNum = self.utils:AddLabelBox( box6b, "", 50, selectionHeight );
	self.sizeSB = self.utils:AddScrollBar( box6b, 16, 0, 20, 200, selectionHeight / 2 );
	
	box6a:AddItem( box6b );
	self.settingsBox:AddItem( box6a );
	
	local triggerButton = Turbine.UI.Lotro.Button();
	triggerButton:SetText( "Show Trigger Options" );
	triggerButton:SetSize( buttonWidth + 100, selectionHeight );
	triggerButton.MouseClick = function( sender, args )
		self.triggerDownWindow:SetPosition( triggerButton:GetLeft(), self.upperBar:GetHeight() + triggerButton:GetTop() - self.triggerDownWindow:GetHeight() + triggerButton:GetHeight() + 20 );
		self:DisplayTriggers( true );
	end
	self.settingsBox:AddItem( triggerButton );

	local colorButton = Turbine.UI.Lotro.Button();
	colorButton:SetText( "Show Color Options" );
	colorButton:SetSize( buttonWidth + 100, selectionHeight );
	colorButton.MouseClick = function( sender, args )
		self.colorDownWindow:SetPosition( colorButton:GetLeft(), self.upperBar:GetHeight() + colorButton:GetTop() - self.colorDownWindow:GetHeight() + colorButton:GetHeight() + 20 );
		self:DisplayColorOptions( true );
	end
	self.settingsBox:AddItem( colorButton );

	
	self:AddCommandsBar();
end

function QuickslotsMenu:DisplaySettings( showQuickslots )
	self.scrollBox:SetVisible( showQuickslots );
	
	local localBarSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );

	self.barName.FocusLost = function(sender, args)
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.barName = self.barName:GetText();
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );		
	end
	self.barName:SetText( localBarSettings.barName );
	
	self.barVisibleCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.visible = self.barVisibleCheckBox.IsChecked;
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.barVisibleCheckBox:SetChecked( localBarSettings.visible );
	self.barLockedCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.locked = self.barLockedCheckBox.IsChecked;
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end	
	self.barLockedCheckBox:SetChecked( localBarSettings.locked );
	self.sb.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.quickslotCount = self.sb:GetValue();
		self.sbNum:SetText( self.sb:GetValue() );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end	
	self.sb:SetValue( localBarSettings.quickslotCount );
	self.sb2.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.quickslotColumns = self.sb2:GetValue();
		self.sb2Num:SetText( self.sb2:GetValue() );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end	
	self.sb2:SetValue( localBarSettings.quickslotColumns );

	self.sbNum:SetText( localBarSettings.quickslotCount );
	self.sb2Num:SetText( localBarSettings.quickslotColumns );

	self.spacingSB.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.quickslotSpacing = self.spacingSB:GetValue();
		self.spacingNum:SetText( barSettings.quickslotSpacing );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.spacingSB:SetValue( localBarSettings.quickslotSpacing );
	self.sizeSB.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.quickslotSize = self.sizeSB:GetValue() + 16;
		self.sizeNum:SetText( barSettings.quickslotSize );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.sizeSB:SetValue( localBarSettings.quickslotSize - 16 );
end
function QuickslotsMenu:SetColors( barSettings )
	theColor = Turbine.UI.Color( barSettings.opacity, barSettings.backgroundColorRed, barSettings.backgroundColorGreen, barSettings.backgroundColorBlue )
	
	self.bgRNum:SetBackColor( theColor );
	self.bgGNum:SetBackColor( theColor );
	self.bgBNum:SetBackColor( theColor );
end

function QuickslotsMenu:AddCommandsBar()
	self.qsCommandsBox = Tonic.UI.AutoListBox();
	self.qsCommandsBox:SetParent( self.settingsBox );
	self.qsCommandsBox:SetBackColor( unselectedColor );
	self.qsCommandsBox:SetOrientation( Turbine.UI.Orientation.Horizontal );
	self.qsCommandsBox:SetVisible( true );

	local removeButton = Turbine.UI.Lotro.Button();
	removeButton:SetText( "Remove Bar" );
	removeButton:SetSize( buttonWidth, selectionHeight );

	removeButton.MouseClick = function( sender, args )
		maitre_d:Remove( tonumber( self.barList:GetSelection() ) );
		self.barList:RemoveItem( self.barList:GetSelection() );
	end
	self.qsCommandsBox:AddItem( removeButton );
	
	local copyButton = Turbine.UI.Lotro.Button();
	copyButton:SetText( "Copy Bar" );
	copyButton:SetSize( buttonWidth, selectionHeight );

	copyButton.MouseClick = function( sender, args )
		local barid = maitre_d:Copy( tonumber( self.barList:GetSelection() ) );
		self.barList:AddItem( barid, barid );
	end
	self.qsCommandsBox:AddItem( copyButton );
	
	local resetButton = Turbine.UI.Lotro.Button();
	resetButton:SetText( "Reset Bar" );
	resetButton:SetSize( buttonWidth, selectionHeight );

	resetButton.MouseClick = function( sender, args )
		maitre_d:Reset( tonumber( self.barList:GetSelection() ) );
	end
	self.qsCommandsBox:AddItem( resetButton );
	
	self.settingsBox:AddItem( self.qsCommandsBox );
	
	self.utils:AddLabelBox( self.settingsBox, "Copy and Reset requre restart of", 300, selectionHeight );
	self.utils:AddLabelBox( self.settingsBox, "the plugin until I fix a bug.", 300, selectionHeight );
end

function QuickslotsMenu:GetSelection()
	return self.barList:GetSelection();
end

function QuickslotsMenu:ClearSelection()
	local settings = theSettingsManager:GetSettings();
	settings.selectedBar = 0;
	self.scrollBox:SetVisible( false );
	self.barList:SetSelection();
end

function QuickslotsMenu:ShouldCheckBeVisible( barSettings )

	if (barSettings.isCombatBar or barSettings.isAlt or barSettings.isControl or barSettings.isShift) then
		barSettings.visible = false;
		self.barVisibleCheckBox:SetChecked( false );
	else
		barSettings.visible = true;
		self.barVisibleCheckBox:SetChecked( true );
	end
end

function QuickslotsMenu:RefreshComboBox( barid )
	self.barList:Clear();
	for key, value in pairs (theSettingsManager:GetBars( QUICKSLOTBAR )) do
		local found = false;
		for i = 1, self.barList:GetItemCount() do
			if ( self.barList:GetItem(i) == key) then
				found = true;
			end
		end
		if ( found == false ) then
			local text = key;
			local barSettings = theSettingsManager:GetBarSettings( key );
			if ( barSettings.barName ~= nil ) then
				text = barSettings.barName;
			end
			self.barList:AddItem( text, key );
		end
	end
	if ( barid ~= nil ) then
		self.barList:SetSelection( barid );
	end
end