-- Created by NuclearTonic
-- If reusing this code, please keep the name of the original author listed
-- in respect for borrowing said authors code.
-- RESPECT!

import "Turbine";
import "Tonic.Utils.Class";
import "Turbine.Gameplay";
import "Tonic.Utils.TableDeepCopy";

SettingsManager = class( Turbine.Object );

function SettingsManager:Constructor()
	self.player = Turbine.Gameplay.LocalPlayer();
	self.PARTIAL = 1;
	self.ALL = 2;
	
	self:ConvertToServer();
--	self:PullServerProfiles();
end

function SettingsManager:ConvertToServer()
	self.settings = Turbine.PluginData.Load( Turbine.DataScope.Character, "TonicBarSettings" );
	if ( self.settings ~= nil ) then
		self.profiles = Turbine.PluginData.Load( Turbine.DataScope.Server, "TonicBarSettings" );
		if ( self.profiles == nil ) then
			self.profiles = {};
		end
		if ( self.profiles[ self.player:GetName() ] == nil ) then
			self.profiles[ self.player:GetName() ] = {};
		end
		self:deepcopy( self.settings, self.profiles[ self.player:GetName() ] );
		
		self.settings = self.profiles[ self.player:GetName() ];
		
		self.settings.version = "v1.0";
		for key, value in pairs (self.settings.bars) do
			value.barType = QUICKSLOTBAR;
			Turbine.Shell.WriteLine( "Correcting Bar: " .. key );
		end
		
		Turbine.PluginData.Save( Turbine.DataScope.Server, "TonicBarSettings", self.settings );
		Turbine.PluginData.Save( Turbine.DataScope.Character, "TonicBarSettings", nil );
	else
		self:LoadSettings();
	end
end

function SettingsManager:PullServerProfiles()
	self.profiles = Turbine.PluginData.Load( Turbine.DataScope.Server, "TonicBarSettings" );
	if ( self.profiles == nil ) then
		self.profiles = {};
	end
end

function SettingsManager:GetProfiles()
	return self.profiles;
end

function SettingsManager:CopyProfile( profileToCopy, copyType )
	for key, value in pairs (maitre_d:GetBars()) do
		maitre_d:Remove( key );
	end
	self.profiles[ self.player:GetName() ] = nil;
	self.profiles[ self.player:GetName() ] = {};
	self:deepcopy( self.profiles[ profileToCopy ], self.profiles[ self.player:GetName() ] );

	self.settings = self.profiles[ self.player:GetName() ];

	if ( copyType ~= self.ALL ) then
		for key, value in pairs ( self.settings.bars ) do
			value.quickslots = nil;
		end
	end

	self:SaveSettings();
	if ( self.settings.bars == nil ) then
		self.settings.bars = { };
	end
	maitre_d:Construct( self.settings.bars );
end

function SettingsManager:GetSettings()
	return self.settings;
end

function SettingsManager:LoadSettings()
	self.profiles = Turbine.PluginData.Load( Turbine.DataScope.Server, "TonicBarSettings" );
	if ( self.profiles == nil ) then
		self.profiles = { };
	end
	local playerSettings = self.profiles[ self.player:GetName() ];
	if ( playerSettings == nil ) then
		playerSettings = {};
	end

	if ( Turbine.Engine:GetLocale() == "de" or Turbine.Engine:GetLocale() == "fr" ) then
		self.settings = { };
		self:deepcopyLoadConvertInts( playerSettings, self.settings );
	else
		self.settings = playerSettings;
	end
	
	if ( self.settings.version == nil or self.settings.version == "v1.0" or self.settings.version == "v1.1" or self.settings.version == "v1.2" or self.settings.version == "v1.3" or self.settings.version == "v1.3.1" or self.settings.version == "v1.4" ) then
		self.settings.version = THEVERSION;
	elseif (self.settings.version == "v0.8" or self.settings.version == "v0.7" or self.settings.version == "V0.6") then
		self.settings.version = THEVERSION;
		for key, value in pairs (self.settings.bars) do
			value.barType = QUICKSLOTBAR;
			Turbine.Shell.WriteLine( "Correcting Bar: " .. key );
		end
		Turbine.PluginData.Save( Turbine.DataScope.Server, "TonicBarSettings", self.settings, self:SaveCompelete( 3 ) );
	elseif (self.settings.version < "V0.6") then
		Turbine.Shell.WriteLine("Version does not match previous version. You might have difficulties and might need to delete your settings for this user.");
		self.settings.version = THEVERSION;
	end
	
	if ( self.settings.bars == nil ) then
		self.settings.bars = { };
	end
	
	if ( self.settings.nextBarId == nil ) then
		self.settings.nextBarId = 1;
	end
	
	if ( self.settings.mainMenuVisible ~= nil ) then
		self.settings.mainMenuVisible = nil;
	end
	
	if ( self.settings.selectedBar == nil )then
		self.settings.selectedBar = 0;
	end
	
	return self.settings;
end

function SettingsManager:SaveSettings()
	if ( Turbine.Engine:GetLocale() == "de" or Turbine.Engine:GetLocale() == "fr" ) then
		local temp = { };
		self:deepcopySaveConvertInts( self.settings, temp );
		self.profiles[ self.player:GetName() ] = temp;
	else
		self.profiles[ self.player:GetName() ] = self.settings;
	end
	Turbine.PluginData.Save( Turbine.DataScope.Server, "TonicBarSettings", self.profiles );
end

function SettingsManager:GetBars( localBarType )
	if ( localBarType == nil ) then
		return self.settings.bars
	else
		self.tempBars = { };
		local i = 1;
		for key, value in pairs (self.settings.bars) do
			if ( value.barType == localBarType and value ~= nil ) then
				self.tempBars[key] = {};
				self:deepcopy( self.settings.bars[key], self.tempBars[key] );
				i = i + 1;
			end
		end
		return self.tempBars;
	end
end

function SettingsManager:GetBarSettings( barid )
	local bar = self.settings.bars[barid]
	if ( bar == nil ) then
		bar = { };
	end

	if ( bar.quickslots == nil ) then
		bar.quickslots = { };
	end
	
	if ( bar.x == nil )then
		bar.x = 103;
	end

	if ( bar.y == nil )then	
		bar.y = 161;
	end
	
	if ( bar.barType == nil )then	
		bar.barType = 1;
	end

	if ( bar.quickslotCount == nil )then	
		bar.quickslotCount = 5;
	end
	
	if ( bar.quickslotColumns == nil )then
		bar.quickslotColumns = 1;
	end
	
	if ( bar.visible == nil )then
		bar.visible = true;
	end
	
	if ( bar.locked == nil )then
		bar.locked = false;
	end
	
	if ( bar.onMouseOver == nil ) then
		bar.onMouseOver = SHOW_EXTENSIONS;
	end
	
	if ( bar.isCombatBar == nil )then
		bar.isCombatBar = false;
	end

	if ( bar.isAlt == nil )then
		bar.isAlt = false;
	end
	
	if ( bar.isControl == nil )then
		bar.isControl = false;
	end
	
	if ( bar.isShift == nil )then
		bar.isShift = false;
	end
	
	if ( bar.opacity == nil )then
		bar.opacity = 1.0;
	end
	
	if ( bar.quickslotSpacing == nil )then
		bar.quickslotSpacing = 1;
	end

	if ( bar.quickslotSize == nil )then
		bar.quickslotSize = 36;
	end

	if ( bar.useBackgroundColor == nil )then
		bar.useBackgroundColor = false;
	end	
	if ( bar.backgroundColorRed == nil )then
		bar.backgroundColorRed = 0;
	end
	if ( bar.backgroundColorGreen == nil )then
		bar.backgroundColorGreen = 0;
	end
	if ( bar.backgroundColorBlue == nil )then
		bar.backgroundColorBlue = 0;
	end
	if ( bar.useFading == nil )then
		bar.useFading = false;
	end	
	if ( bar.fadeOpacity == nil )then
		bar.fadeOpacity = 1;
	end
	if ( bar.healthTrigger == nil )then
		bar.healthTrigger = 0.25;
	end
	if ( bar.powerTrigger == nil )then
		bar.powerTrigger = 0.25;
	end
	return bar
end

function SettingsManager:SetBarSettings(barid, bar, doNotRefresh)
	self.settings.bars[barid] = bar;

	self:SaveSettings();
	if ( doNotRefresh == nil and maitre_d ~= nil ) then
		maitre_d:RefreshBars();
	end
end

function SettingsManager:SaveQuickslots( bar, qSlots )
	if ( self.loading ) then
		return;
	end

	bar.quickslots = nil;
	bar.quickslots = { };
	
	for key, value in pairs (qSlots) do
		local shortcut = value:GetShortcut();
		if( shortcut:GetType() ~= 0 and shortcut:GetData() ~= "" ) then
			if ( bar.quickslots[key] == nil ) then
				bar.quickslots[key] = { };
			end
			bar.quickslots[key].Type = shortcut:GetType();
			bar.quickslots[key].Data = shortcut:GetData();
		end
	end
	self:SaveSettings();
end

function SettingsManager:LoadQuickslots( bar, qSlots )
	self.loading = true;
	for key, value in pairs (bar.quickslots) do
		if( value.Type ~= 0 and value.Data ~= "" ) then
			local shortcut = Turbine.UI.Lotro.Shortcut( value.Type, value.Data );
			if ( pcall( SetShortcut, shortcut, qSlots, key ) == false ) then
				Turbine.Shell.WriteLine( "TonicBars has found an invalid quickslot, it has been removed, but you were saved by: Pengoros!!" );
				value = nil;
				dirty = true;
			end
		end
	end
	self.loading = false;
	
	if (dirty == true) then
		self:SaveQuickslots( bar, qSlots )
	end
end

function SetShortcut( shortcut, qSlots, key )
	qSlots[key]:SetShortcut( shortcut );
end

function SettingsManager:IncrementNextId()
	self.settings.nextBarId = self.settings.nextBarId + 1;
	self:SaveSettings();
end


function SettingsManager:GetWrapperSettings()
	local theWrapperSettings = self.settings.wrapperSettings;

	if ( type( theWrapperSettings ) ~= "table" ) then
		theWrapperSettings = { };
		local settings = Turbine.PluginData.Load( Turbine.DataScope.Character, "TonicBarWrapper", self.SuccessfullLoad );
		if ( settings ~= nil ) then
			theWrapperSettings.positionX = settings.positionX
			theWrapperSettings.positionY = settings.positionY
			theWrapperSettings.visible   = settings.visible
		end
	end

	if ( not theWrapperSettings.positionX ) then
		theWrapperSettings.positionX = 0; 
	end

	if ( not theWrapperSettings.positionY ) then
		theWrapperSettings.positionY = 0;
	end
	
	if ( theWrapperSettings.visible == nil ) then
		theWrapperSettings.visible = true;
	end
	return theWrapperSettings;
end

function SettingsManager:SetWrapperSettings( theWrapperSettings )
	self.settings.wrapperSettings = theWrapperSettings;
	self:SaveSettings();
end

function SettingsManager:SuccessfullLoad()
end

function SettingsManager:deepcopySaveConvertInts(a, b)
        if type(a) ~= "table" or type(b) ~= "table" then
                error("both parameters must be of type table but recieved " ..type(a)..
                        " and " .. type(b));
        else
                for k,v in pairs(a) do
                        -- if the type is a table, we'll need to recurse.
                        if type(v) ~= "table" then
							local l, y;
							if ( type( k ) == "number" ) then
								l = "INTEGER:" .. tostring( k );
							else
								l = k;
							end
							if ( type( v ) == "number" ) then
								y = "INTEGER:" .. tostring( v );
							else
								y = v;
							end
                            b[l] = y;
                        else
                            local x = {}
                            self:deepcopySaveConvertInts(v, x);

							local l;
							if ( type( k ) == "number" ) then
								l = "INTEGER:" .. tostring( k );
							else
								l = k;
							end
							b[l] = x;
                        end       
                end
        end
        return b;
end


function SettingsManager:deepcopyLoadConvertInts(a, b)
        if type(a) ~= "table" or type(b) ~= "table" then
                error("both parameters must be of type table but recieved " ..type(a)..
                        " and " .. type(b));
        else
                for k,v in pairs(a) do
                        -- if the type is a table, we'll need to recurse.
                        if type(v) ~= "table" then
							local l, y;
							if ( type( k ) == "string" ) then
								local temp, count = string.gsub( k, "INTEGER:", "");
								if ( count > 0 ) then
									l = tonumber( temp );
								else
									l = temp;
								end
							else
								l = k;
							end
							if ( type( v ) == "string" ) then
								local temp, count = string.gsub( v, "INTEGER:", "");
								if ( count > 0 ) then
									y = tonumber( temp );
								else
									y = temp;
								end
							else
								y = v;
							end
                            b[l] = y;
                        else
                            local x = {}
                            self:deepcopyLoadConvertInts(v, x);

							local l;
							if ( type( k ) == "string" ) then
								local temp, count = string.gsub( k, "INTEGER:", "");
								if ( count > 0 ) then
									l = tonumber( temp );
								else
									l = temp;
								end
							else
								l = k;
							end
							b[l] = x;
                        end       
                end
        end
        return b;
end

function SettingsManager:deepcopy(a, b)
        if type(a) ~= "table" or type(b) ~= "table" then
                error("both parameters must be of type table but recieved " ..type(a)..
                        " and " .. type(b));
        else
                for k,v in pairs(a) do
                        -- if the type is a table, we'll need to recurse.
                        if type(v) ~= "table" then
                                b[k] = v;
                        else
                                local x = {}
                                self:deepcopy(v, x);
                                b[k] = x;
                        end       
                end
        end
        return b;
end